@@ -20,14 +20,13 @@ class Handler(object):
   }
 
   def _transformer_handler(self, transformation, **kwargs):
-    transformer = self.__class__.transformer_instances.get(transformation, self.__class__.EXPOSED_TRANSFORMERS[transformation](pretrained_translator=self.__class__.pretrained_translator))
+    transformer = self.__class__.transformer_instances.get(transformation, self.__class__.EXPOSED_TRANSFORMERS[transformation]())
     self.__class__.transformer_instances[transformation] = transformer
     return transformer.transform(input_lines=self.input_lines, src_lang=self.src_lang, **kwargs)
     
   def __init__(self, input_lines=[], src_lang='en', **kwargs):
     self.input_lines = input_lines
     self.src_lang = src_lang
-    self.__class__.pretrained_translator = kwargs.get("pretrained_translator")
     for k in self.__class__.EXPOSED_TRANSFORMERS:
       handler = lambda x: lambda **kwargs: self._transformer_handler(transformation=x, **kwargs)
       handler = handler(k)
